@@ -27,9 +27,9 @@ ledetExe = 'LEDET_v1_07_02_02_25May2020.exe'
 def CompleteRun():
     start = time.time()
     a = ParametersLEDET()
-    a.readLEDETExcel(testfile9)
-    Sw = MinMaxSweep(a, 10)
-    MagnetName = 'MCBXH_CopperWedges_ThCool'
+    a.readLEDETExcel(testfile2)
+    Sw = MinMaxSweep(a, 2)
+    MagnetName = 'MBRB'
 
     ##8mag
     # Sw.addParameterToSweep('l_magnet', 2.56, 4.8)
@@ -53,8 +53,8 @@ def CompleteRun():
     # Sw.addHeliumCrossSection(3, 6, basePoints=4)
 
     ## MCBXH_CopperWedges -1
-    Sw.addParameterToSweep('f_ro_eff_inGroup', 0.1, 3)
-    Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
+    # Sw.addParameterToSweep('f_ro_eff_inGroup', 0.1, 3)
+    # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
     # Sw.addParameterToSweep('l_magnet', 0.056, 0.14)
     # Sw.addQuenchSweep("tStartQuench",[1,1,1,1,1,1],[-0.2, -0.21, -0.22, -0.23, -0.24, -0.25])
     # Sw.addQuenchSweep("tStartQuench", [[1, 730],[321,1050],[1, 730],[321,1050],[1, 730],[321,1050],[1, 730],[321,1050]],
@@ -65,13 +65,13 @@ def CompleteRun():
     # Sw.addParameterToSweep('RRR_Cu_inGroup', 100, 300)
 
     ## Current Sweep
-    # Sw.addCurrentSweep(6650, 30)
+    Sw.addCurrentSweep(6650, 30)
 
     Sw.generatePermutations()
     end = time.time()
     print("Time:", end-start)
     start = time.time()
-    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\",OffsetNumber=100)
+    Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\",OffsetNumber=0)
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MBRC\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCD\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCO\\Input\\")
@@ -111,9 +111,9 @@ def CompleteRun():
     # EvaluateSimulations('C:\\cernbox\\Validation_MCBX_HV\\LEDET Validation\\2nd Sweep-RRR_fro_tQ_THCOOL\\Output\\Txt Files',
     #                     'MCBXH_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
     #                      Sw, Mat=False, showBestFit = 20)
-    EvaluateSimulations("C:\\cernbox\\TEMP\\",
-                        'MCBXV_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXV2.R1_2017-04-20_PM_I_ARAW.csv',
-                         Sw, Mat=False)
+    # EvaluateSimulations("C:\\cernbox\\TEMP\\",
+    #                     'MCBXV_CopperWedges_ThCool', 'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXV2.R1_2017-04-20_PM_I_ARAW.csv',
+    #                      Sw, Mat=False)
     # EvaluateSimulations("C:\\cernbox\\TEMP2\\",
     #                     'MCBXH_CopperWedges_ThCool',
     #                     'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
@@ -154,73 +154,78 @@ def testvQ():
 
 def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
     a = QuenchPlanAnalysis(FileName_TDMS, FileName_Sim)
-    Coil108 = [[],
-               np.concatenate((np.linspace(29, 45, 17), np.linspace(229, 245, 17))),
-               np.concatenate((np.linspace(46, 49, 4), np.linspace(246, 249, 4))),
-               [],
-               np.array([50]),
-               [],
-               np.array([250]),
-               [],
-               [],
-               np.array([28]),
-               [],
-               np.array([228]),
-               np.concatenate((np.linspace(17, 27, 11), np.linspace(217, 227, 11))),
-               np.concatenate((np.linspace(1, 16, 16), np.linspace(201, 216, 16)))]
-
-    Coil109 = [[],
-               np.concatenate((np.linspace(329, 345, 17), np.linspace(129, 145, 17))),
-               np.concatenate((np.linspace(146, 149, 4), np.linspace(346, 349, 4))),
-               [],
-               np.array([150]),
-               [],
-               np.array([350]),
-               [],
-               [],
-               np.array([128]),
-               [],
-               np.array([328]),
-               np.concatenate((np.linspace(117, 127, 11), np.linspace(317, 327, 11))),
-               np.concatenate((np.linspace(101, 116, 16), np.linspace(301, 316, 16)))]
-
-    Coil110 = [[],
-               np.concatenate((np.linspace(79, 95, 17), np.linspace(279, 295, 17))),
-               np.concatenate((np.linspace(96, 99, 4), np.linspace(296, 299, 4))),
-               [],
-               np.array([100]),
-               [],
-               np.array([300]),
-               [],
-               [],
-               np.array([78]),
-               [],
-               np.array([278]),
-               np.concatenate((np.linspace(267, 277, 11), np.linspace(67, 77, 11))),
-               np.concatenate((np.linspace(51, 66, 16), np.linspace(251, 266, 16)))]
-
-    Coil111 = [[],
-               np.concatenate((np.linspace(179, 195, 17), np.linspace(379, 395, 17))),
-               np.concatenate((np.linspace(196, 199, 4), np.linspace(396, 399, 4))),
-               [],
-               np.array([200]),
-               [],
-               np.array([400]),
-               [],
-               [],
-               np.array([178]),
-               [],
-               np.array([378]),
-               np.concatenate((np.linspace(367, 377, 11), np.linspace(167, 177, 11))),
-               np.concatenate((np.linspace(151, 166, 16), np.linspace(351, 366, 16)))]
+    Coil108 = {'C108_I1_I2':[],
+               'C108_I2_I3':np.concatenate((np.linspace(29, 45, 17), np.linspace(229, 245, 17))),
+               'C108_I3_I4':np.concatenate((np.linspace(46, 49, 4), np.linspace(246, 249, 4))),
+               'C108_I4_I5':[],
+               'C108_I5_I6':np.array([50]),
+               'C108_I6_I7':[],
+               'C108_I7_I8':np.array([250]),
+               'C108_I8_O1':[],
+               'C108_O1_O2':[],
+               'C108_O2_O3':np.array([28]),
+               'C108_O3_O4':[],
+               'C108_O4_O5':np.array([228]),
+               'C108_O5_O6':np.concatenate((np.linspace(17, 27, 11), np.linspace(217, 227, 11))),
+               'C108_O6_O7':np.concatenate((np.linspace(1, 16, 16), np.linspace(201, 216, 16))),
+               'C108_O7_O8':[]}
+    Coil109 = {'C109_I1_I2':[],
+               'C109_I2_I3':np.concatenate((np.linspace(329, 345, 17), np.linspace(129, 145, 17))),
+               'C109_I3_I4':np.concatenate((np.linspace(146, 149, 4), np.linspace(346, 349, 4))),
+               'C109_I4_I5':[],
+               'C109_I5_I6':np.array([150]),
+               'C109_I6_I7':[],
+               'C109_I7_I8':np.array([350]),
+               'C109_I8_O1':[],
+               'C109_O1_O2':[],
+               'C109_O2_O3':np.array([128]),
+               'C109_O3_O4':[],
+               'C109_O4_O5':np.array([328]),
+               'C109_O5_O6':np.concatenate((np.linspace(117, 127, 11), np.linspace(317, 327, 11))),
+               'C109_O6_O7':np.concatenate((np.linspace(101, 116, 16), np.linspace(301, 316, 16))),
+               'C109_O7_O8':[]}
+    Coil110 = {'C110_I1_I2':[],
+               'C110_I2_I3':np.concatenate((np.linspace(79, 95, 17), np.linspace(279, 295, 17))),
+               'C110_I3_I4':np.concatenate((np.linspace(96, 99, 4), np.linspace(296, 299, 4))),
+               'C110_I4_I5':[],
+               'C110_I5_I6':np.array([100]),
+               'C110_I6_I7':[],
+               'C110_I7_I8':np.array([300]),
+               'C110_I8_O1':[],
+               'C110_O1_O2':[],
+               'C110_O2_O3':np.array([78]),
+               'C110_O3_O4':[],
+               'C110_O4_O5':np.array([278]),
+               'C110_O5_O6':np.concatenate((np.linspace(267, 277, 11), np.linspace(67, 77, 11))),
+               'C110_O6_O7':np.concatenate((np.linspace(51, 66, 16), np.linspace(251, 266, 16))),
+               'C110_O7_O8':[]}
+    Coil111 = {'C111_I1_I2':[],
+               'C111_I2_I3':np.concatenate((np.linspace(179, 195, 17), np.linspace(379, 395, 17))),
+               'C111_I3_I4':np.concatenate((np.linspace(196, 199, 4), np.linspace(396, 399, 4))),
+               'C111_I4_I5':[],
+               'C111_I5_I6':np.array([200]),
+               'C111_I6_I7':[],
+               'C111_I7_I8':np.array([400]),
+               'C111_I8_O1':[],
+               'C111_O1_O2':[],
+               'C111_O2_O3':np.array([178]),
+               'C111_O3_O4':[],
+               'C111_O4_O5':np.array([378]),
+               'C111_O5_O6':np.concatenate((np.linspace(367, 377, 11), np.linspace(167, 177, 11))),
+               'C111_O6_O7':np.concatenate((np.linspace(151, 166, 16), np.linspace(351, 366, 16))),
+               'C111_O7_O8':[]}
     a.ProvideTurnsToCoilStructure([Coil108,Coil109,Coil110,Coil111])
-    a.QuenchPlanAnalysis(Plot = 1)
+    a.QuenchPlanAnalysis(Plot = 0)
+    a.FindQuenchTDMS(0.1, 0.005)
     return a
 
 # testConsistencyChecks()
 
-CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_0.xlsx", "C:\cernbox\MasterThesis\QuenchPlans\MQXF_V2_2924.xlsx")
+# CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_0.xlsx", "C:\cernbox\MasterThesis\QuenchPlans\MQXF_V2_2924.xlsx")
 # CompareLEDETParameters("C:\\cernbox\\steam-notebook-api\\test\\ledet\\resources\\TestFile_1.xlsx", "C:\\cernbox\\steam-notebook-api\\test\\ledet\\TestFile1.xlsx")
+# CompareLEDETParameters("C:\cernbox\MasterThesis\QuenchPlans\MQXF_V2_5400.xlsx", "C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_14.xlsx")
+# CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_18.xlsx", "C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_15.xlsx")
+# CompareLEDETParameters("C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\MCBXV_CopperWedges_ThCool_0.xlsx", "C:\cernbox\TEMP2\MCBXH_CopperWedges_ThCool_100.xlsx")
 
 # test_readLEDETExcel()
 # test_setgetAttributes()
@@ -228,9 +233,11 @@ CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_0.xlsx",
 # test_SetUpSimulations()
 # test_EvaluateSimulations()
 
-# CompleteRun()
+CompleteRun()
 
-# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\MQXFS4b\\HCMQXSM001-CR000042__H1810171217_a041(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111846_a008(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810171217_a041(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810121049_a012(0).tdms"
 # sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_27.mat"
 # a = testQuenchPlanAnalysis(td_data, sim_data)
 
