@@ -23,7 +23,7 @@ def RunSimulations(LEDETFolder, LEDETExe, MagnetName, Simulations = 'All', RunSi
     else:
         SimNumbers = Simulations
 
-    df = pd.read_excel(StartFile, header=None)
+    df = pd.read_excel(StartFile, header=None, engine='openpyxl')
     df.rename(columns={0: 'a', 1: 'b', 2: 'c'}, inplace=True)
     df.loc[df['b'] == 'currFolder', 'c'] = LEDETFolder + "\\LEDET"
     df.loc[df['b'] == 'nameMagnet', 'c'] = MagnetName
